#puppet_enterprise

This is the puppet_enterprise module.
This module is designed to be a friendly interface for installing
and managing components of Puppet Enterprise.  

The manifests in `manifests/profile/` are profile modules which
are to be used as the access points to configure their corresponding service.
The profiles configure the standalone services, **Master** for instance, as well
as the desirable configurations for the services to communicate with other Puppet Enterprise
services appropriately, allowing a **Master** to talk to **PuppetDB**.  

The profiles we support are:  
* **CA-Master**  
* **Additional Compilation-Masters**  
* **MCollective**  
* **ActiveMQ**  
* **PuppetDB**  
* **Database**  
* **Console**  

### Common parameters
##### `$ca`
The hostname of the **CA** to use for generating and downloading certs.
##### `$certname`
The *certname* which Puppet will use to manage the certificates and configure the service.
##### `$localcacert`
The location of the `ca.pem` to use for the **CA** cert, defaults to `/etc/puppetlabs/puppet/ssl/certs/ca.pem`, the location of the agent certs.
##### `$localcacrl`
Same as above.
##### `$manage_package`
A *boolean* valued parameter specifying if Puppet should declare the required packages for the services, useful for separating the installation, where we do wish to manage packages, and the management,
where we do not wish to manage them, of Puppet Enterprise services.
##### `$manage_certs`
A *boolean* valued parameter specifying if Puppet should declare use the `$puppet_enterprise::certs` type to download and manage the credentials for the service in question.
##### `$manage_config`
A *boolean* valued parameter specifying if Puppet should manage the config files for that service. This is especially useful for services such as the **Console** where
we cannot manage individual settings of user configuration files and have to manage files as a whole, thus setting this value to *false* will make sure custom settings aren't overwritten.
##### **Note on variable names**
We use the following naming convention for separating client and server variables. Client of a service will have `$service_port` as the variable name for the port to contact the service, whereas the service
will have `$service_listen_port` as the variable to distinguish itself.
### CA-Master
```puppet
class puppet_enterprise::master (
  ...
  $console,
  $console_port,
  $console_server_certname,
  $console_client_certname = 'pe-internal-dashboard',
  $puppetdb,
  $puppetdb_port,
  $classifier = $console,
  $classifier_port,
  ...
  $manage_repo,
  $repo_base_path,
)
```
To have a master be configured as a **CA** you must leave `$ca = undef`, for **Additional Compilation-Masters** you will set `$ca = $the_cas_hostname`.
### Additional Compilation-Masters
See above.
### MCollective
### ActiveMQ
### PuppetDB
To disable the PuppetDB plaintext connector simply pass an empty string for the `$listen_port` param in the profile.
### Database
```puppet
class puppet_enterprise::profile::database(
  ...
  $database_listen_addresses,
  ...
  $manage_example_service = true,
  $example_service_database_name,
  $example_service_database_user,
  $example_service_database_password,
  ...
)
```
### Console
**TODO** Document this section after we have eliminated console-auth management and merged console-services into it as well.


Running tests
-------

### Spec tests
```
  bundle exec rake spec
```

### Manual verification

It's a good idea to manually verify that your changes don't break the PE install.

  * If you don't already have puppet installed, `gem install puppet`
  * `bundle exec puppet module build`
  * Copy the module tarball from the `pkg/` directory to the `modules/` directory of a PE installer
  * Remove the old module from the PE installer `modules/` directory
  * Run the install and verify that your changes are present

License
-------
Puppet Enterprise


Support
-------

Please log tickets and issues at our [Projects site](http://projects.puppetlabs.com)
