class puppet_enterprise::console_services(
  $proxy_idle_timeout    = undef,
  $client_certname       = $puppet_enterprise::params::console_client_certname,
  $dashboard_port        = $puppet_enterprise::params::dashboard_listen_port,
  $classifier_host       = 'localhost',
  $classifier_port       = $puppet_enterprise::params::console_services_api_listen_port,
  $classifier_url_prefix = $puppet_enterprise::params::classifier_url_prefix,
  $rbac_host             = 'localhost',
  $rbac_port             = $puppet_enterprise::params::console_services_api_listen_port,
  $activity_host         = 'localhost',
  $activity_port         = $puppet_enterprise::params::console_services_api_listen_port,
  $activity_url_prefix   = $puppet_enterprise::params::activity_url_prefix,
  $puppetdb_host         = 'localhost',
  $puppetdb_port         = $puppet_enterprise::params::puppetdb_ssl_listen_port,
  $localcacert           = $puppet_enterprise::params::localcacert,
  $java_args             = $puppet_enterprise::params::console_services_java_args,
) inherits puppet_enterprise::params {

  puppet_enterprise::trapperkeeper::console_services { 'console-services':
    client_certname       => $client_certname,
    proxy_idle_timeout    => $proxy_idle_timeout,
    dashboard_port        => $dashboard_port,
    classifier_host       => $classifier_host,
    classifier_port       => $classifier_port,
    classifier_url_prefix => $classifier_url_prefix,
    puppetdb_host         => $puppetdb_host,
    puppetdb_port         => $puppetdb_port,
    rbac_host             => $rbac_host,
    rbac_port             => $rbac_port,
    activity_host         => $activity_host,
    activity_port         => $activity_port,
    activity_url_prefix   => $activity_url_prefix,
    localcacert           => $localcacert,
    notify                => Service[ 'pe-console-services' ],
  }

  if !pe_empty($java_args) {
    $console_initconf = "${puppet_enterprise::params::defaults_dir}/pe-console-services"

    create_resources(
      'pe_ini_subsetting',
      create_java_args_subsettings_hash(
        'pe-console-services',
        $java_args,
        { path => $console_initconf,
          require => Package['pe-console-services'],
          notify => Service['pe-console-services'],
        })
    )
  }

  service { 'pe-console-services':
    ensure => running,
    enable => true,
  }

}
