class puppet_enterprise::profile::amq::broker (
  $brokername                         = $puppet_enterprise::params::activemq_brokername,
  $decrease_network_consumer_priority = true,
  $duplex                             = true,
  $dynamic_only                       = true,
  $heap_mb                            = $puppet_enterprise::params::activemq_heap_mb,
  $keystore_password                  = $puppet_enterprise::params::activemq_java_ks_password,
  $truststore_password                = $puppet_enterprise::params::activemq_java_ts_password,
  $network_ttl                        = $puppet_enterprise::params::activemq_network_ttl,
  $openwire_protocol                  = $puppet_enterprise::params::openwire_protocol,
  $openwire_transport_options         = $puppet_enterprise::params::activemq_transport_options,
  $stomp_protocol                     = $puppet_enterprise::params::stomp_protocol,
  $stomp_transport_options            = $puppet_enterprise::params::activemq_transport_options,
  $stomp_port                         = $puppet_enterprise::mcollective_middleware_port,
  $stomp_user                         = $puppet_enterprise::mcollective_middleware_user,
  $stomp_password                     = $puppet_enterprise::mcollective_middleware_password,
  $enable_web_console                 = false,
  $memory_usage                       = '200mb',
  $store_usage                        = '1gb',
  $temp_usage                         = '1gb',
) inherits puppet_enterprise {

  class { 'puppet_enterprise::amq':
    brokername => $brokername,
  }

  # Template uses:
  # - $puppetversion (fact)
  # - $heap_mb
  file { "${puppet_enterprise::params::defaults_dir}/pe-activemq":
    ensure  => file,
    content => template('puppet_enterprise/amq/activemq.defaults.erb'),
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0755',
  }

  # The pe-activemq package lays down a broker named 'localhost' which
  # we do not want to exist. Remove it
  puppet_enterprise::amq::config::broker { 'remove default localhost':
    brokername    => 'localhost',
    broker_ensure => 'absent',
  }

  puppet_enterprise::amq::config::broker { $brokername:
    brokername => $brokername,
  }

  class { 'puppet_enterprise::amq::certs':
    brokername          => $brokername,
    keystore_password   => $keystore_password,
    truststore_password => $truststore_password,
  }

  puppet_enterprise::amq::config::ssl_context { "${brokername}-ssl-context":
    brokername          => $brokername,
    keystore_password   => $keystore_password,
    truststore_password => $truststore_password,
  }

  @@puppet_enterprise::amq::config::network_connector { "export: ${brokername}-topic":
    brokername                         => $brokername,
    connector_name                     => "${brokername}-topic",
    decrease_network_consumer_priority => $decrease_network_consumer_priority,
    duplex                             => $duplex,
    dynamic_only                       => $dynamic_only,
    network_ttl                        => $network_ttl,
    openwire_protocol                  => $openwire_protocol,
    stomp_password                     => $stomp_password,
    stomp_user                         => $stomp_user,
    tag                                => 'pe-amq-network-connectors',
  }

  @@puppet_enterprise::amq::config::network_connector { "export: ${brokername}-queue":
    brokername                         => $brokername,
    connector_name                     => "${brokername}-queue",
    decrease_network_consumer_priority => $decrease_network_consumer_priority,
    duplex                             => $duplex,
    dynamic_only                       => $dynamic_only,
    network_ttl                        => $network_ttl,
    openwire_protocol                  => $openwire_protocol,
    stomp_password                     => $stomp_password,
    stomp_user                         => $stomp_user,
    tag                                => 'pe-amq-network-connectors',
  }

  puppet_enterprise::amq::config::management_context { "${brokername} - managementContext":
    brokername => $brokername,
  }

  puppet_enterprise::amq::config::destination_policy_entry { "${brokername}-topic->":
    brokername                   => $brokername,
    destination_type             => 'topic',
    target_destination           => '>',
    enable_producer_flow_control => false,
    memory_limit                 => '5mb'
  }

  puppet_enterprise::amq::config::destination_policy_entry { "${brokername}-queue->":
    brokername                   => $brokername,
    destination_type             => 'queue',
    target_destination           => '>',
    enable_producer_flow_control => false,
    memory_limit                 => '20mb'
  }

  puppet_enterprise::amq::config::destination_policy_entry { "${brokername}-queue-*.reply.>":
    brokername                      => $brokername,
    destination_type                => 'queue',
    target_destination              => '*.reply.>',
    enable_gc_inactive_destinations => true,
    inactive_timout_before_gc       => '300000',
  }

  puppet_enterprise::amq::config::transport_connector { "${brokername}-openwire-transport":
    brokername     => $brokername,
    transport_name => 'openwire',
    transport_uri  => "${openwire_protocol}://0.0.0.0:61616",
    transport_options => $openwire_transport_options,
  }

  puppet_enterprise::amq::config::transport_connector { "${brokername}-stomp-transport":
    brokername        => $brokername,
    transport_name    => 'stomp+ssl',
    transport_uri     => "${stomp_protocol}://0.0.0.0:${stomp_port}",
    transport_options => $stomp_transport_options,
  }

  puppet_enterprise::amq::config::statistics_broker_plugin { "${brokername}-statisticsBrokerPlugin":
    brokername => $brokername
  }

  puppet_enterprise::amq::config::timestamping_broker_plugin { "${brokername}-timeStampingBrokerPlugin":
    brokername               => $brokername,
    zero_expiration_override => 30000,
  }

  puppet_enterprise::amq::config::simple_authentication_user { "${brokername}-simple_auth_user-mcollective":
    brokername => $brokername,
    groups     => 'mcollective,admins,everyone',
    password   => $stomp_password,
    username   => 'mcollective',
  }

  puppet_enterprise::amq::config::authorization_plugin_entry { "${brokername}-authorization-queue->":
    brokername         => $brokername,
    destination_type   => 'queue',
    target_destination => '>',
    write              => 'admins',
    read               => 'admins',
    admin              => 'admins',
  }

  puppet_enterprise::amq::config::authorization_plugin_entry { "${brokername}-authorization-topic->":
    brokername         => $brokername,
    destination_type   => 'topic',
    target_destination => '>',
    write              => 'admins',
    read               => 'admins',
    admin              => 'admins',
  }

  puppet_enterprise::amq::config::authorization_plugin_entry { "${brokername}-authorization-queue-mcollective.>":
    brokername         => $brokername,
    destination_type   => 'queue',
    target_destination => 'mcollective.>',
    write              => 'mcollective',
    read               => 'mcollective',
    admin              => 'mcollective',
  }

  puppet_enterprise::amq::config::authorization_plugin_entry { "${brokername}-authorization-topic-mcollective.>":
    brokername         => $brokername,
    destination_type   => 'topic',
    target_destination => 'mcollective.>',
    write              => 'mcollective',
    read               => 'mcollective',
    admin              => 'mcollective',
  }

  puppet_enterprise::amq::config::authorization_plugin_entry { "${brokername}-authorization-topic-ActiveMQ.Advisory.>":
    brokername         => $brokername,
    destination_type   => 'topic',
    target_destination => 'ActiveMQ.Advisory.>',
    write              => 'everyone',
    read               => 'everyone',
    admin              => 'everyone',
  }

  puppet_enterprise::amq::config::web_console { "${brokername} - web console - ${enable_web_console}":
    console_ensure  => pe_bool2str($enable_web_console),
  }

  puppet_enterprise::amq::config::system_usage { "${brokername} - systemusage":
    brokername   => $brokername,
    memory_usage => $memory_usage,
    store_usage  => $store_usage,
    temp_usage   => $temp_usage,
  }
}
